aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--mailkit/addr.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/mailkit/addr.go b/mailkit/addr.go
index c087be0..455c020 100644
--- a/mailkit/addr.go
+++ b/mailkit/addr.go
@@ -1,11 +1,11 @@
package mailkit
// Strip_angle_brackets strips a single "<" from the
// front of the string and a single ">" from the back
// of the string. If either are present, stripped
// returns true; if both are present, balanced also
// returns true.
-func Strip_angle_brackets(x string) (result string, stripped bool, balanced bool) {
+func StripAngleBrackets(x string) (result string, stripped bool, balanced bool) {
var tmp string
if x[0] == '<' {
tmp = x[1:]
@@ -1,11 +1,11 @@
package mailkit
-// Strip_angle_brackets strips a single "<" from the
+// StripAngleBrackets strips a single "<" from the
// front of the string and a single ">" from the back
// of the string. If either are present, stripped